#!/bin/bash
# shellcheck disable=SC1091 # Cannot resolve paths in variables

PROJECT_HOME="$(realpath -s --relative-to . "$(dirname "$0")/..")" || exit
. "$PROJECT_HOME/scripts/util.sh" || exit

get_project_name
get_project_type

SSH_HOME="$HOME/.ssh"
if ! [ -e "$SSH_HOME/id_ed25519_vscode" ]; then
	echo $"Generating $SSH_HOME/id_ed25519_vscode"
	ssh-keygen -t ed25519 -f "$SSH_HOME/id_ed25519_vscode"
fi

if [[ "$PROJECT_TYPE" == "flutter" ]]; then
	CONFIG_DIR="$PROJECT_HOME/config"
	FLUTTER_CUSTOM_DEVICES="flutter_custom_devices.json"

	if [[ ! -e "$HOME/.$FLUTTER_CUSTOM_DEVICES" ]]; then
		cp "$CONFIG_DIR/$FLUTTER_CUSTOM_DEVICES" "$HOME/.$FLUTTER_CUSTOM_DEVICES"
	else
		if ! cmp "$HOME/.$FLUTTER_CUSTOM_DEVICES" "$CONFIG_DIR/$FLUTTER_CUSTOM_DEVICES" >/dev/null; then
			if prompt_yesno y $".$FLUTTER_CUSTOM_DEVICES already exists, overwrite? [Y/n]"; then
				cp "$CONFIG_DIR/$FLUTTER_CUSTOM_DEVICES" "$HOME/.$FLUTTER_CUSTOM_DEVICES"
			fi
		fi
	fi
fi

# remove known hosts in case of error on reinstall
rm -vf config/ssh_known_hosts

echo $"Environment ready"
